Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Named pipes are used on Windows for local (and remote) IPC. Where a Unix system would use a Unix domain socket, a Windows system will probably used a named pipe.
To build:
oasis setup
makeTo run a server:
./_build/src/pipecat.native -l \\\\.\\pipe\\mynamedpipeTo run a client:
./_build/src/pipecat.native \\\\.\\pipe\\mynamedpipeNamed pipes have a number of significant differences to Unix domain sockets to be careful. These bindings attempt to disable remote connections and disable security context impersonation but there may be other issues.